
/*

Standard Parallel Port (SPP)
----------------------------

Data Port
---------

Offset		Name		Read/Write	Bit No.	Properties
Base + 0	Data Port	Write (*1)	Bit 7	Data 7		Pin 9
						Bit 6	Data 6		Pin 8
						Bit 5	Data 5		Pin 7
						Bit 4	Data 4		Pin 6
						Bit 3	Data 3		Pin 5
						Bit 2	Data 2		Pin 4
						Bit 1	Data 1		Pin 3
						Bit 0	Data 0		Pin 2

*1) : If the Port is Bi-Directional then Read and Write Operations can be 
performed on the Data Register. 

The base address, usually called the Data Port or Data Register is simply used 
for outputting data on the Parallel Port's data lines (Pins 2-9). This register 
is normally a write only port. If you read from the port, you should get the 
last byte sent. However if your port is bi-directional, you can receive data on 
this address.

Status Port
-----------

Offset		Name		Read/Write	Bit No.	Properties
Base + 1	Status Port	Read Only	Bit 7	Busy		Pin 11
						Bit 6	Ack		Pin 10
						Bit 5	Paper Out	Pin 12
						Bit 4	Select In	Pin 13
						Bit 3	Error		Pin 15
						Bit 2	IRQ (Not)
						Bit 1	Reserved
						Bit 0	Reserved


The Status Port (base address + 1) is a read only port. Any data written to this 
port will be ignored. The Status Port is made up of 5 input lines (Pins 10,11,12,13 
& 15), a IRQ status register and two reserved bits. Please note that Bit 7 (Busy) 
is a active low input. E.g. If bit 7 happens to show a logic 0, this means that 
there is +5v at pin 11. Likewise with Bit 2. (nIRQ) If this bit shows a '1' then 
an interrupt has not occurred. 

Control Port
------------

Offset		Name		Read/Write	Bit No.	Properties
Base + 2	Control Port	Read/Write	Bit 7	Unused
						Bit 6	Unused
						Bit 5	Enable Bi-Directional Port
						Bit 4	Enable IRQ Via Ack Line
						Bit 3	Select Printer			Pin 17
						Bit 2	Initialize Printer (Reset)	Pin 16
						Bit 1	Auto Linefeed			Pin 14
						Bit 0	Strobe				Pin 1


The Control Port (base address + 2) was intended as a write only port. When a printer 
is attached to the Parallel Port, four "controls" are used. These are Strobe, Auto 
Linefeed, Initialize and Select Printer, all of which are inverted except Initialize. 

The printer would not send a signal to initialize the computer, nor would it tell the 
computer to use auto linefeed. However these four outputs can also be used for inputs. 
If the computer has placed a pin high (e.g. +5v) and your device wanted to take it low, 
you would effectively short out the port, causing a conflict on that pin. Therefore 
these lines are "open collector" outputs (or open drain for CMOS devices). This means 
that it has two states. A low state (0v) and a high impedance state (open circuit). 

Normally the Printer Card will have internal pull-up resistors, but as you would expect, 
not all will. Some may just have open collector outputs, while others may even have normal 
totem pole outputs. In order to make your device work correctly on as many Printer Ports 
as possible, you can use an external resistor as well. Should you already have an internal 
resistor, then it will act in Parallel with it, or if you have Totem pole outputs, the 
resistor will act as a load. 

An external 4.7k resistor can be used to pull the pin high. I wouldn't use anything lower, 
just in case you do have an internal pull up resistor, as the external resistor would act 
in parallel giving effectively, a lower value pull up resistor. When in high impedance state 
the pin on the Parallel Port is high (+5v). When in this state, your external device can pull 
the pin low and have the control port change read a different value. This way the 4 pins of 
the Control Port can be used for bi-directional data transfer. However the Control Port must 
be set to xxxx0100 to be able to read data, that is all pins to be +5v at the port so that 
you can pull it down to GND (logic 0). 

Bits 4 & 5 are internal controls. Bit four will enable the IRQ (See Using the Parallel Ports 
IRQ) and Bit 5 will enable the bi-directional port meaning that you can input 8 bits using 
(DATA0-7). This mode is only possible if your card supports it. Bits 6 & 7 are reserved. Any 
writes to these two bits will be ignored.

*/

/*
	NOTE: the windows version of this little lib needs giveio.sys (on 2000/NT/XP)
	
*/

#ifndef __LPTPORT_H__
#define __LPTPORT_H__

#include <stdint.h>

int lptport_init(void);
int lptport_close(void);


int lptport_getstatus_busy(void);

int lptport_setcontrol_strobe(int outbit);
int lptport_setcontrol_autofeed(int outbit);

int lptport_setdata(uint8_t data);

#endif /* __LPTPORT_H__ */
